@@ -21,7 +21,7 @@ class ChainedStore(BaseStore):
     def __init__(self, stores=None):
         super(ChainedStore, self).__init__()
         if not stores:
-            stores = []
+            raise ValueError("you didn't specify any internal stores for this ChainedStore to operate on")
         self.__stores = stores
     
     def put(self, obj):
