@@ -36,7 +36,7 @@ class MemcacheStore(BaseStore):
         # get default lifetime
         lifetime = self.__lifetime_cb(obj)
         if lifetime is None:
-            return None
+            return 0
             
         else:
             # TODO: memoize this block of code for speed
