@@ -84,23 +84,25 @@ class SqlAlchemyStore(BaseStore):
     Non-SQLAlchemy objects will be ignored by this store."""
     
     engine = property(lambda self: self.__session.bind)
-    """the engine that is connected to this session"""
+    """the SQLAlchemy Engine object that this store is bound to"""
     
-    def __init__(self, uri=None, engine=None, session=None):
+    def __init__(self, uri=None, engine=None, **kwargs):
+        """Create a new SqlAlchemyStore.  When given a connection string (uri)
+        or SQLAlchemy Engine (engine), this Store will create it's own internal
+        SQLAlchemy Session to manage objects.
+        """
 
         super(SqlAlchemyStore, self).__init__()
         
         # get the session
-        if session:
-            if uri or engine:
-                raise ValueError("you cannot specify a session, and also provide a connection string URI or engine")
-            else:
-                # we're good
-                self.__session = session
+        if "session" in kwargs:
+            # we no longer allow initialization with a pre-existing session object, there
+            # are too many issues with this approach at the moment
+            raise DeprecationWarning("cannot instantiate a SqlAlchemyStore with a pre-existing session object")
         else:
             # no session, we have to make one
             # first we need to get the engine
-            from sqlalchemy.orm import scoped_session, sessionmaker
+            from sqlalchemy.orm import sessionmaker
             
             if uri and engine:
                 raise ValueError("you can only provide either a connection string URI or an engine, not both")
@@ -108,7 +110,7 @@ class SqlAlchemyStore(BaseStore):
                 from sqlalchemy import create_engine
                 engine = create_engine(uri)
             elif not engine:
-                raise ValueError("you must give a connection string URI, or an engine, or a bound session")
+                raise ValueError("you must give a connection string URI, or an engine, or a session")
             
             # we can create the bound session now
             self.__session = sessionmaker(autoflush=True, bind=engine)()
@@ -152,26 +154,22 @@ class SqlAlchemyStore(BaseStore):
     def _sa_put(self, obj):
         from sqlalchemy.exceptions import InvalidRequestError
         try:
-            self.__session.save_or_update(obj)
+            self.__session.add(obj)
             self.__session.commit()
         except InvalidRequestError:
-            # this is likely due to mismatched instances from cache
+            # this is likely due to mismatched session attachment, do the more expensive 'merge' operation
             self.__session.merge(obj)
             self.__session.commit()
 
     def _sa_batch_put(self, objs):
         from sqlalchemy.exceptions import InvalidRequestError
-        
-        # TODO: look at bulk_update?
-        # save all in the session
-        for obj in objs:
-            self.__session.save_or_update(obj)
     
         # commit the session
         try:
+            self.__session.add_all(objs)
             self.__session.commit()
         except InvalidRequestError:
-            # this is likely due to mismatched instances from cache
+            # this is likely due to mismatched session attachment, do the more expensive 'merge' operation
             for obj in objs:
                 self.__session.merge(obj)
             self.__session.commit()
@@ -182,7 +180,7 @@ class SqlAlchemyStore(BaseStore):
             self.__session.delete(obj)
             self.__session.commit()
         except InvalidRequestError:
-            # this is likely due to mismatched instances from cache
+            # this is likely due to mismatched session attachment, do the more expensive 'merge' operation
             obj = self.__session.merge(obj)
             self.__session.delete(obj)
             self.__session.commit()
@@ -196,7 +194,7 @@ class SqlAlchemyStore(BaseStore):
                 self.__session.delete(obj)
             self.__session.commit()
         except InvalidRequestError:
-            # this is likely due to mismatched instances from cache
+            # this is likely due to mismatched session attachment, do the more expensive 'merge' operation
             for obj in objs:
                 obj = self.__session.merge(obj)
                 self.__session.delete(obj)
